package nl.niftysystems.android.contactcarouselwidget;

/*
 * Copyright (C) 2009 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import android.app.PendingIntent;
import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.BroadcastReceiver;
import android.content.ComponentName;
import android.content.ContentResolver;
import android.content.ContentUris;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.net.Uri;
import android.provider.Contacts.People;
import android.provider.Contacts.Phones;
import android.widget.RemoteViews;

/**
 * ContactCarouselWidget, by Niftysystems 2009. 
 * 
 * This widget displays large photos of your favorite contacts. 
 * When clicked on, the phone calls that contact.
 * Browse through your contacts using the left and right buttons
 */
public class ContactCarouselWidget extends AppWidgetProvider {
    // Current person id counter
	static int currentId = 0;
	
    @Override
    public void onUpdate(Context context, AppWidgetManager appWidgetManager,
            int[] appWidgetIds) {
    	updateAppWidget(context, appWidgetManager, appWidgetIds[0]);
    }
    
    static void updateAppWidget(Context context, AppWidgetManager appWidgetManager,
            int appWidgetId) {
        
    	RemoteViews updateViews = null;
        ContentResolver cr = context.getContentResolver();
        
        // Form an array specifying which columns to return. 
        String[] projection = new String[] {
        								People._ID,
        								People.NAME,
        								People.PRIMARY_PHONE_ID,
        								People.STARRED
                                  };

        // Only select starred people
        String selection = "People.STARRED=1";
        
        // Create a cursor that can be used to query the current rows data
        Cursor cur = cr.query(People.CONTENT_URI, projection, selection, null, null);
        
        // Build an update that holds the updated widget contents 
        updateViews = new RemoteViews(context.getPackageName(), R.layout.widget_carousel);
        
        //Check if there are any records
        if (cur.moveToPosition(currentId)) {

            int idColumn = cur.getColumnIndex(People._ID);
            int nameColumn = cur.getColumnIndex(People.NAME);
            String name = cur.getString(nameColumn);
        	
        	//Get the contactphoto for the current contact
            Uri uri = ContentUris.withAppendedId(People.CONTENT_URI, cur.getLong(idColumn));
            Bitmap bitmap = People.loadContactPhoto(context, uri, R.drawable.icon, null);

            //Set the acquired data in the new remoteview
            updateViews.setImageViewBitmap(R.id.contact_image, bitmap);
            updateViews.setTextViewText(R.id.contact_name, name);
            
            //When user clicks on left button, call the previousContact class            
            Intent leftClickIntent = new Intent(context, previousContact.class);
            PendingIntent pendingleftClickIntent = PendingIntent.getBroadcast(context,
                    0 /* no requestCode */, leftClickIntent, 0 /* no flags */);
            updateViews.setOnClickPendingIntent(R.id.button_left, pendingleftClickIntent);

            //When user clicks on right button, call the nextContact class            
            Intent rightClickIntent = new Intent(context, nextContact.class);
            PendingIntent pendingrightClickIntent = PendingIntent.getBroadcast(context,
                    0 /* no requestCode */, rightClickIntent, 0 /* no flags */);
            updateViews.setOnClickPendingIntent(R.id.button_right, pendingrightClickIntent);
            
            //When user clicks on image, call the contact
            Intent defineIntent3 = new Intent(Intent.ACTION_CALL);
            long phoneId = cur.getLong(cur.getColumnIndex(People.PRIMARY_PHONE_ID));
            defineIntent3.setData(ContentUris.withAppendedId(Phones.CONTENT_URI, phoneId));
            PendingIntent pendingIntent3 = PendingIntent.getActivity(context, 0, defineIntent3, 0);
            updateViews.setOnClickPendingIntent(R.id.contact_image, pendingIntent3);
            updateViews.setOnClickPendingIntent(R.id.contact_name, pendingIntent3);
            
        } else { // The currentid index does not contain a record
        	if (currentId < 0) {
        		currentId = 0;
        	} else {
        		currentId--;
        	}
        }
        
        // Push update for this widget to the home screen
        appWidgetManager.updateAppWidget(appWidgetId, updateViews);
    }
    
    /* This class handles the leftbutton click event by decreasing
     * the idcounter and building a new remoteview to show to the user */
    static public class previousContact extends BroadcastReceiver {
    	@Override
		public void onReceive(Context context, Intent intent) {
			//Decrease the id counter
			currentId--;
			
			//Get the appwidgetmanager to get all appwidget id's and to pass in update call
			AppWidgetManager gm = AppWidgetManager.getInstance(context);
            int[] appWidgetIds = gm.getAppWidgetIds(new ComponentName(context, ContactCarouselWidget.class));
          
            final int N = appWidgetIds.length;
            //Update all widgets with the new id
            for (int i=0; i<N; i++) {
   			     ContactCarouselWidget.updateAppWidget(context, gm, appWidgetIds[i]);
            }
	    }
    }
 
    /* This class handles the rightbutton click event by increasing
     * the idcounter and building a new remoteview to show to the user */
    static public class nextContact extends BroadcastReceiver {

		@Override
		public void onReceive(Context context, Intent intent) {
			//Raise the id counter
			currentId++;
			
			//Get the appwidgetmanager to get all appwidget id's and to pass in update call
			AppWidgetManager gm = AppWidgetManager.getInstance(context);
            int[] appWidgetIds = gm.getAppWidgetIds(new ComponentName(context, ContactCarouselWidget.class));
          
            final int N = appWidgetIds.length;
            //Update all widgets with the new id
            for (int i=0; i<N; i++) {
   			     ContactCarouselWidget.updateAppWidget(context, gm, appWidgetIds[i]);
            }
	    }
    }	
}

