package nl.niftysystems.android.publictimelinewidget;

/*
 * Copyright (C) 2009 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import nl.niftysystems.android.publictimelinewidget.ServiceHelper.ApiException;
import nl.niftysystems.android.publictimelinewidget.ServiceHelper.ParseException;

import android.app.PendingIntent;
import android.app.Service;
import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.os.IBinder;
import android.util.Log;
import android.widget.RemoteViews;

/**
 * PublicTimelineWidget, by Niftysystems 2009. 
 * 
 * This widget displays the last tweet from twitter. To build an update we
 * spawn a background {@link Service} to perfom the JSON API queries to the
 * twitter server.
 */
public class PublicTimelineWidget extends AppWidgetProvider {
    @Override
    public void onUpdate(	Context context, AppWidgetManager appWidgetManager,
            				int[] appWidgetIds) {
    		context.startService(new Intent(context, UpdateService.class));
    }
    
    public static class UpdateService extends Service {
        @Override
        public void onStart(Intent intent, int startId) {
            // Build the widget update for today
            RemoteViews updateViews = buildUpdate(this);
            
            // Push update for this widget to the home screen
            ComponentName thisWidget = new ComponentName(this, PublicTimelineWidget.class);
            AppWidgetManager manager = AppWidgetManager.getInstance(this);
            manager.updateAppWidget(thisWidget, updateViews);
        }

        /**
         * Build a widget update to show the latest tweet from twitter.com
         * Note: Will block until the online API returns.
         */
        public RemoteViews buildUpdate(Context context) {
            // Get the resources, including some strings and context dependant variables
            Resources res = context.getResources();
            
            // Initialize the new RemoteViews and page content string array.
            RemoteViews updateViews = null;
            String[] pageContent = null;
            
            try {
            	// Prepare the user agent by setting some context dependant variables
                ServiceHelper.prepareUserAgent(context);
                
                // Try querying the Twitter API for the latest tweets
                pageContent = ServiceHelper.getPageContent(res.getString(R.string.service_url));
                
            } catch (ApiException e) {
                Log.e("PublicTimelineWidget", "Couldn't contact API", e);
            } catch (ParseException e) {
                Log.e("PublicTimelineWidget", "Couldn't parse API response", e);
            }

            // Build an update that holds the updated widget contents 
            updateViews = new RemoteViews(context.getPackageName(), R.layout.widget_word);
            
            // Set the user and tweet
            updateViews.setTextViewText(R.id.screen_name, pageContent[0]);
            updateViews.setTextViewText(R.id.text, pageContent[1]);
             
            //When user clicks on widget, call the UpdateService class            
            Intent defineIntent = new Intent(context, UpdateService.class);
            PendingIntent pendingIntent = PendingIntent.getService(context,
                    0 /* no requestCode */, defineIntent, 0 /* no flags */);
            updateViews.setOnClickPendingIntent(R.id.widget, pendingIntent);
            
            return updateViews;
        }
        
        @Override
        public IBinder onBind(Intent intent) {
            // We don't need to bind to this service
            return null;
        }
    }
}

