package nl.niftysystems.android.wikipediasearchwidget;

import nl.niftysystems.android.wikipediasearchwidget.R;
import nl.niftysystems.android.wikipediasearchwidget.ServiceHelper;
import nl.niftysystems.android.wikipediasearchwidget.ServiceHelper.ApiException;
import nl.niftysystems.android.wikipediasearchwidget.ServiceHelper.ParseException;
import android.app.PendingIntent;
import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.util.Log;
import android.view.View;
import android.widget.RadioButton;
import android.widget.RemoteViews;

/**
 * WikipediaSearchWidget, by Niftysystems 2009. 
 * 
 * This widget displays a search bar and searches 
 * wikipedia for the searchtext when launched
 */
public class WikipediaSearchWidget extends AppWidgetProvider  {

	public static String TAG = "WikipediaSearchWidget";
	
	@Override
	public void onUpdate(Context context, AppWidgetManager appWidgetManager,
			int[] appWidgetIds) {      
        final int N = appWidgetIds.length;
        Log.e(TAG, "appwidgetids.length=" + N);
        
        //Update all widgets
        for (int i=0; i<N; i++) {
        	// Build the widget update for today using the current appwidgetid
            //RemoteViews updateViews = buildUpdate(context, appWidgetIds[i], context.getString(R.string.default_search_term));
        	
            
            // Push update for this specific widget to the home screen
            AppWidgetManager manager = AppWidgetManager.getInstance(context);
            //manager.updateAppWidget(appWidgetIds[i], updateViews);
        	updateAppWidget(context, manager, appWidgetIds[i], context.getString(R.string.default_search_term), -1);
        }
		//updateAppWidget(context, appWidgetManager, appWidgetIds[0], context.getString(R.string.default_search_term));
    }
    
    static void updateAppWidget(Context context, AppWidgetManager appWidgetManager,
            int appWidgetId, String search, int language) {
		
        // Build the widget update for today
        RemoteViews view = buildUpdate(context, appWidgetId, search, language);

        // Tell the AppWidgetManager to perform an update on the current App Widget
        appWidgetManager.updateAppWidget(appWidgetId, view);
	}

    /**
     * Build a widget update to show the latest tweet from twitter.com
     * Note: Will block until the online API returns.
     */
    public static RemoteViews buildUpdate(Context context, int appWidgetId, String search, int language) {
        // Get the resources, including some strings and context dependant variables
        Resources res = context.getResources();
        
        // Initialize the new RemoteViews and page content string array.
        RemoteViews updateViews = null;
        String[] pageContent = null;
        

        
        try {
        	// Prepare the user agent by setting some context dependant variables
            ServiceHelper.prepareUserAgent(context);
            
            
            switch(language) {
            	case R.id.radiobutton_en:
            		// Try querying the Wikipedia API for the requested search query
                    pageContent = ServiceHelper.getPageContent(search, res.getString(R.string.service_url_en));
                    break;
            	case R.id.radiobutton_nl:
            		// Try querying the Wikipedia API for the requested search query
                    pageContent = ServiceHelper.getPageContent(search, res.getString(R.string.service_url_nl));
                    break;
            	default:
            		// Try querying the Wikipedia API for the requested search query
                    pageContent = ServiceHelper.getPageContent(search, res.getString(R.string.service_url_en));
                    break;
            }
            
            
            
        } catch (ApiException e) {
            Log.e(TAG, "Couldn't contact API", e);
        } catch (ParseException e) {
            Log.e(TAG, "Couldn't parse API response", e);
        }

        // Build an update that holds the updated widget contents 
        updateViews = new RemoteViews(context.getPackageName(), R.layout.main);
        
        // Set the text and description
        updateViews.setTextViewText(R.id.wikipedia_title, pageContent[0]);
        updateViews.setTextViewText(R.id.wikipedia_text, pageContent[1]);
         
        //When user clicks on widget, call the UpdateService class
        Intent configure = new Intent(context, WikipediaSearchWidgetConfigure.class);
        configure.putExtra(AppWidgetManager.EXTRA_APPWIDGET_ID, appWidgetId);       
        PendingIntent pendingConfigure = PendingIntent.getActivity(context, 0, configure, 0);
        updateViews.setOnClickPendingIntent(R.id.widget, pendingConfigure);
        
        return updateViews;
    }
	
}
