package nl.niftysystems.android.wikipediasearchwidget;

/*
 * Copyright (C) 2008 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import android.app.Activity;
import android.appwidget.AppWidgetManager;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.RadioGroup;

/**
 * The configuration screen for the WikipediaSearchWidget.
 */
public class WikipediaSearchWidgetConfigure extends Activity {
    static final String TAG = "WikipediaSearchWidgetConfigure";

    int mAppWidgetId = AppWidgetManager.INVALID_APPWIDGET_ID;
    EditText search;

    public WikipediaSearchWidgetConfigure() {
        super();
    }

    @Override
    public void onCreate(Bundle icicle) {
        super.onCreate(icicle);

        // Set the result to CANCELED.  This will cause the widget host to cancel
        // out of the widget placement if they press the back button.
        setResult(RESULT_CANCELED);

        // Set the view layout resource to use.
        setContentView(R.layout.appwidget_configure);

        // Find the Search input field
        search = (EditText)findViewById(R.id.search);

        // Bind the action for the save button.
        findViewById(R.id.save_button).setOnClickListener(mOnClickListener);

        // Find the widget id from the intent. 
        Intent intent = getIntent();
        Bundle extras = intent.getExtras();
        if (extras != null) {
            mAppWidgetId = extras.getInt(
                    AppWidgetManager.EXTRA_APPWIDGET_ID, AppWidgetManager.INVALID_APPWIDGET_ID);
        }

        // If they gave us an intent without the widget id, just bail.
        if (mAppWidgetId == AppWidgetManager.INVALID_APPWIDGET_ID) {
            
        	//HIER GAAT HET FOUT
        	
        	finish();
        }
        
        // Set the inputfield with default search term
        search.setText(R.string.default_search_term);
    }

    // Create a new onclick listener for the "ok" button
    View.OnClickListener mOnClickListener = new View.OnClickListener() {
        public void onClick(View v) {
            final Context context = WikipediaSearchWidgetConfigure.this;

            // Find the widget id from the intent. 
            Intent intent = getIntent();
            Bundle extras = intent.getExtras();
            if (extras != null) {
                mAppWidgetId = extras.getInt(
                        AppWidgetManager.EXTRA_APPWIDGET_ID, AppWidgetManager.INVALID_APPWIDGET_ID);
            }
            Log.d(TAG, "Debug appwidget id = " + mAppWidgetId);
            
            RadioGroup languagebuttons = (RadioGroup) findViewById(R.id.languagebuttons);
            
            // Push widget update to surface with newly set search
            AppWidgetManager appWidgetManager = AppWidgetManager.getInstance(context);
            WikipediaSearchWidget.updateAppWidget(context, appWidgetManager,
                    mAppWidgetId, search.getText().toString(), languagebuttons.getCheckedRadioButtonId());
            Log.d(TAG, "Debug searchtext = " + search.getText().toString());

            // Make sure we pass back the original appWidgetId
            Intent resultValue = new Intent();
            resultValue.putExtra(AppWidgetManager.EXTRA_APPWIDGET_ID, mAppWidgetId);
            setResult(RESULT_OK, resultValue);
            finish();
        }
    };
}