package nl.niftysystems.android.xboxlivestatswidget;

/*
 * Copyright (C) 2008 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import android.app.Activity;
import android.appwidget.AppWidgetManager;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;

/**
 * The configuration screen for the XboxLiveStatsWidget.
 */
public class XboxLiveStatsWidgetConfigure extends Activity {
    static final String TAG = "XboxLiveStatsWidgetConfigure";
    
    public static final String PREFS_NAME
	= "nl.niftysystems.android.XboxLiveStatsWidget";
    
    private static final String PREF_GAMERTAG = "gamertag_";

    int mAppWidgetId = AppWidgetManager.INVALID_APPWIDGET_ID;
    EditText gamertag;

    public XboxLiveStatsWidgetConfigure() {
        super();
    }

    @Override
    public void onCreate(Bundle icicle) {
        super.onCreate(icicle);

        // Set the result to CANCELED.  This will cause the widget host to cancel
        // out of the widget placement if they press the back button.
        setResult(RESULT_CANCELED);

        // Set the view layout resource to use.
        setContentView(R.layout.appwidget_configure);

        // Find the Gamertag input field
        gamertag = (EditText)findViewById(R.id.gamertag);

        // Bind the action for the save button.
        findViewById(R.id.save_button).setOnClickListener(mOnClickListener);

        // Find the widget id from the intent. 
        Intent intent = getIntent();
        Bundle extras = intent.getExtras();
        if (extras != null) {
            mAppWidgetId = extras.getInt(
                    AppWidgetManager.EXTRA_APPWIDGET_ID, AppWidgetManager.INVALID_APPWIDGET_ID);
        }

        // If they gave us an intent without the widget id, just bail.
        if (mAppWidgetId == AppWidgetManager.INVALID_APPWIDGET_ID) {
            finish();
        }
        
        // Set the inputfield with the last set gamertag from saved preferences
        gamertag.setText(loadTitlePref(XboxLiveStatsWidgetConfigure.this, mAppWidgetId));
    }

    // Create a new onclick listener for the "ok" button
    View.OnClickListener mOnClickListener = new View.OnClickListener() {
        public void onClick(View v) {
            final Context context = XboxLiveStatsWidgetConfigure.this;

            // When the button is clicked, save the string in our prefs
            String saveGamertag = gamertag.getText().toString();
            saveTitlePref(context, mAppWidgetId, saveGamertag);

            // Push widget update to surface with newly set gamertag
            AppWidgetManager appWidgetManager = AppWidgetManager.getInstance(context);
            XboxLiveStatsWidget.updateAppWidget(context, appWidgetManager,
                    mAppWidgetId, saveGamertag);

            // Make sure we pass back the original appWidgetId
            Intent resultValue = new Intent();
            resultValue.putExtra(AppWidgetManager.EXTRA_APPWIDGET_ID, mAppWidgetId);
            setResult(RESULT_OK, resultValue);
            finish();
        }
    };

    // Write the gamertag to the SharedPreferences object for this widget
    static void saveTitlePref(Context context, int appWidgetId, String saveGamertag) {
        SharedPreferences.Editor prefs = context.getSharedPreferences(PREFS_NAME, 0).edit();
        prefs.putString(PREF_GAMERTAG + appWidgetId, saveGamertag);
        prefs.commit();
    }

	// Read the gamertag from the SharedPreferences object for this widget.
    // If there is no preference saved, get the default from a resource
    static String loadTitlePref(Context context, int appWidgetId) {
        SharedPreferences prefs = context.getSharedPreferences(PREFS_NAME, 0);
        String gamertag = prefs.getString(PREF_GAMERTAG + appWidgetId, null);
        if (gamertag != null) {
            return gamertag;
        } else {
            return context.getString(R.string.gamertag_default);
        }
    }
}